@@ -1,5 +1,5 @@
 """The partial transpose."""
-from typing import List, Union
+from __future__ import annotations
 
 import numpy as np
 
@@ -10,10 +10,10 @@ from toqito.helper import expr_as_np_array, np_array_as_expr
 
 
 def partial_transpose(
-    rho: Union[np.ndarray, Variable],
-    sys: Union[List[int], np.ndarray, int] = 2,
-    dim: Union[List[int], np.ndarray] = None,
-) -> Union[np.ndarray, Expression]:
+    rho: np.ndarray | Variable,
+    sys: list[int] | np.ndarray | int = 2,
+    dim: list[int] | np.ndarray = None,
+) -> np.ndarray | Expression:
     r"""Compute the partial transpose of a matrix [WikPtrans]_.
 
     The *partial transpose* is defined as
@@ -105,11 +105,11 @@ def partial_transpose(
     ==========
     .. [WikPtrans] Wikipedia: Partial transpose
         https://en.wikipedia.org/w/index.php?title=Partial_transpose
-
     :param rho: A matrix.
     :param sys: Scalar or vector specifying the size of the subsystems.
     :param dim: Dimension of the subsystems. If :code:`None`, all dimensions
                 are assumed to be equal.
+    :raises ValueError: If matrix dimensions are not square.
     :returns: The partial transpose of matrix :code:`rho`.
     """
     # If the input matrix is a CVX variable for an SDP, we convert it to a
@@ -134,7 +134,7 @@ def partial_transpose(
     if isinstance(sys, int):
         sys = np.array([sys])
 
-    num_sys = len(dim)
+    num_sys = max(dim.shape)
     # Allow the user to enter a single number for dim.
     if num_sys == 1:
         dim = np.array([dim, list(rho.shape)[0] / dim])
@@ -192,7 +192,7 @@ def partial_transpose(
     )
 
     # Return the subsystems back to their original positions.
-    dim[[0, 1], sys - 1] = dim[[1, 0], sys - 1]
+    dim[:, sys - 1] = np.flipud(dim[:, sys - 1])
 
     dim = dim[:, (np.array(perm) - 1).tolist()]
 
